@@ -1,9 +1,9 @@
 ;;; sdicf.el --- Search library for SDIC format dictionary
-;;; $Id: sdicf.el,v 1.18 1999/09/03 05:24:13 tsuchiya Exp $
+;;; $Id: sdicf.el,v 1.20 2002/07/02 11:17:46 tsuchiya Exp $
 
-;; Copyright (C) 1999 TSUCHIYA Masatoshi <tsuchiya@pine.kuee.kyoto-u.ac.jp>
+;; Copyright (C) 1999 TSUCHIYA Masatoshi <tsuchiya@namazu.org>
 
-;; Author: TSUCHIYA Masatoshi <tsuchiya@pine.kuee.kyoto-u.ac.jp>
+;; Author: TSUCHIYA Masatoshi <tsuchiya@namazu.org>
 ;;	   NISHIDA Keisuke <knishida@ring.aist.go.jp>
 ;; Created: 1 Feb 1999
 ;; Version: 0.9
@@ -64,6 +64,9 @@
 			  exec-path))
 		programs))))
 
+(defvar sdicf-default-directory (expand-file-name "~/")
+  "*Default directory for executing command.")
+
 (defvar sdicf-egrep-command (sdicf-find-program "egrep" "egrep.exe" "grep" "grep.exe")
   "*Executable file name of egrep")
 
@@ -213,7 +216,8 @@ CODING-SYSTEM $B0J30$N0z?t$N0UL#$O(B insert-file-contents $B$HF1$8(B"
 (defun sdicf-call-process (program coding-system &optional infile buffer display &rest args) "\
 CODING-SYSTEM $B$rL@<(E*$K;XDj$7$F(B call-process $B$r8F$S=P$9(B
 CODING-SYSTEM $B0J30$N0z?t$N0UL#$O(B call-process $B$HF1$8(B"
-  (let ((coding-system-for-read coding-system)
+  (let ((default-directory sdicf-default-directory)
+	(coding-system-for-read coding-system)
 	(coding-system-for-write coding-system)
 	(process-input-coding-system coding-system)
 	(process-output-coding-system coding-system)
@@ -224,7 +228,8 @@ CODING-SYSTEM $B0J30$N0z?t$N0UL#$O(B call-process $B$HF1$8(B"
 (defun sdicf-start-process (name buffer program coding-system &rest args) "\
 start-process $B$r<B9T$7$?8e!"@8@.$5$l$?%W%m%;%9$K(B CODING-SYSTEM $B$r@_Dj$9$k(B
 CODING-SYSTEM $B0J30$N0z?t$N0UL#$O(B start-process $B$HF1$8(B"  
-  (let ((proc (apply 'start-process name buffer program args)))
+  (let* ((default-directory sdicf-default-directory)
+	 (proc (apply 'start-process name buffer program args)))
     (if (fboundp 'set-process-coding-system)
 	(set-process-coding-system proc coding-system coding-system)
       (set-process-input-coding-system proc coding-system)
